from fastapi import APIRouter
from typing import Dict, Optional
from reviewsense.api.schemas.product_review_input import ProductReviewInput
from reviewsense.services.ReviewService import ReviewService


router = APIRouter()
review_service = ReviewService()

app.add_middleware(
    CORSMiddleware,
    allow_origins=["http://localhost:3000"],
    allow_credentials=True,
    allow_methods=["*"],
    allow_headers=["*"],
)

@router.post("/calculate_ratings/", response_model=Dict[str, Optional[float]])
async def calculate_ratings(input_data: ProductReviewInput):
    """
    Endpoint to calculate feature-specific ratings
    
    Args:
        input_data (ProductReviewInput): Input data for review processing
    
    Returns:
        Dictionary of feature ratings
    """
    # Add new review if provided
    if input_data.new_review:
        review_service.add_review(
            product_id=input_data.product_id, 
            review=input_data.new_review
        )
    
    # Fetch and analyze reviews
    reviews_by_feature = review_service.fetch_reviews(
        product_id=input_data.product_id, 
        features=input_data.features
    )
    
    # Generate and return feature ratings
    return review_service.generate_feature_ratings(reviews_by_feature)
