from pydantic_settings import BaseSettings
from functools import lru_cache

class Settings(BaseSettings):
    """Application configuration settings"""
    ASTRA_DB_API_ENDPOINT: str
    ASTRA_DB_APPLICATION_TOKEN: str
    ASTRA_DB_NAMESPACE: str
    
    # Default settings
    EMBEDDING_MODEL: str = "sentence-transformers/all-mpnet-base-v2"
    
    class Config:
        env_file = ".env"
        env_file_encoding = "utf-8"
        extra = "allow"  # Allow extra fields

@lru_cache()
def get_settings():
    """
    Cached settings retrieval to optimize performance
    
    Returns:
        Settings: Configured application settings
    """
    return Settings()
