# src/reviewsense/core/database.py
from functools import lru_cache
from langchain_huggingface import HuggingFaceEmbeddings
from langchain_astradb import AstraDBVectorStore
from reviewsense.core.config import get_settings

@lru_cache(maxsize=1)
def get_vector_store(
    collection_name: str = "android_phone_reviews", 
    embedding_model: str = "sentence-transformers/all-mpnet-base-v2"
):
    """
    Create a singleton vector store instance
    
    Args:
        collection_name (str): Database collection name
        embedding_model (str): Embedding model to use
    
    Returns:
        AstraDBVectorStore: Configured vector store instance
    """
    settings = get_settings()
    
    # Initialize embeddings
    embeddings = HuggingFaceEmbeddings(model_name=embedding_model)
    
    # Create and return vector store
    return AstraDBVectorStore(
        collection_name=collection_name,
        embedding=embeddings,
        api_endpoint=settings.ASTRA_DB_API_ENDPOINT,
        token=settings.ASTRA_DB_APPLICATION_TOKEN,
        namespace=settings.ASTRA_DB_NAMESPACE,
    )