# services/review_fetcher.py

from typing import List, Dict
from .retrieval import get_vector_store

class ReviewFetcher:
    """Class for fetching reviews from the vector store"""

    def __init__(self):
        self.vector_store = get_vector_store()

    def fetch_reviews(self, product_id: str, features: List[str], threshold: float = 0.6) -> Dict[str, List[str]]:
        feature_reviews = {}

        for feature in features:
            filter_criteria = {"title": product_id}
            documents = self.vector_store.similarity_search_with_score_id(query=self.generate_feature_query(feature), k=100, filter=filter_criteria)

            filtered_reviews = [doc.page_content for doc, score, _ in documents if score > threshold]
            feature_reviews[feature] = filtered_reviews

        return feature_reviews
    def generate_feature_query(self, feature: str) -> str:
        """
        Generate semantic search query for different product features
        
        Args:
            feature (str): Product feature to search
        
        Returns:
            str: Semantic search query
        """
        feature_queries = {
            "battery": "battery performance, battery life, charging speed, power consumption, battery drain, long-lasting battery",
            "backup": "data backup, storage capacity, backup options, cloud storage, data protection, file recovery",
            "design": "build quality, aesthetic design, material, form factor, ergonomics, look and feel, physical appearance",
            "display": "screen quality, display resolution, color accuracy, brightness, viewing angles, screen technology, display performance"
        }
        
        # Default to feature name if not found
        return feature_queries.get(feature.lower(), feature)
