# services/review_rater.py

from typing import Dict, List, Optional
import numpy as np
from langchain_huggingface import HuggingFaceEmbeddings
from transformers import pipeline

class ReviewRater:
    """Class for generating feature-specific ratings based on sentiment analysis"""

    def __init__(self):
        self.sentiment_analyzer = pipeline("sentiment-analysis")

    def generate_feature_ratings(self, reviews_by_feature: Dict[str, List[str]]) -> Dict[str, Optional[float]]:
        feature_ratings = {}

        for feature, reviews in reviews_by_feature.items():
            if not reviews:
                feature_ratings[feature] = None
                continue
            
            ratings = []
            for review in reviews:
                sentiment = self.sentiment_analyzer(review)[0]
                
                if "positive" in sentiment["label"].lower():
                    ratings.append(5)
                elif "negative" in sentiment["label"].lower():
                    ratings.append(1)
                else:
                    ratings.append(3)

            feature_ratings[feature] = round(np.mean(ratings), 1) if ratings else None

        return feature_ratings
